@@ -1,4 +1,4 @@
-.First.lib <- function(lib,pkg) {
+.onLoad <- function(lib, pkg) {
 	library.dynam("deldir", pkg, lib)
 	ver <- read.dcf(file.path(lib, pkg, "DESCRIPTION"), "Version")
         packageStartupMessage(paste(pkg, ver))
